# Diagonal Directed Graph Visualization

Functionality to print a DAG as ASCII art and automatically determine the order in which to print the nodes.
A directed version of the bull graph would look as follows:

```text
0-+
  +-1-+---+
      +-2-+
          +-3-+
              +-4
```